#!/bin/bash
#########################################################################
#
# File:         om_xmatters.sh
# Description:  This file is the interface between the HP OM notification
#		service and xMatters.
# Language:     Shell
# Package:      HP OpenView IT/Operations to xMatters Integration
#
# (c) Copyright xMatters Systems, Inc.  2008
#
#########################################################################

### Initial variables to set

# home directory for xMatters Integration Agent
XM_HOME=/opt/xmatters/integrationagent
APClient=${XM_HOME}/bin/APClient.bin

# OpC directory for OpenView Operations
OpC=/opt/OV/bin/OpC

# AgentClientID passed to xMatters to indicate portion of APAgent.xml file to use
client=hpoml-1-0-1

# Optional log file to store calls to this shell script, comment out to disable
#logfile=${XM_HOME}/log/om_xmatters.log

############################
#
# Exit values:
# ------------
#    0    successful
#    1    unexpected problem encountered when calling APClient.bin
#
# Passed Parameters from Trouble Ticket
# and Notification Service Manager (opcttnsm):
# ----------------------------------------------------------------------
# Parameters
#
#  1: Message ID
#  2: Source node
#  3: Source node type
#  4: Date created
#  5: Time created
#  6: Date received
#  7: Time received
#  8: Application
#  9: Message group
# 10: Object
# 11: Severity
# 12: Responsible operators
# 13: Message text
# 14: Instruction / xMatters Voice Tag (if configured)
# 15: Custom message attributes (name=value pairs separated with ;;)
# 16: Suppressed duplicates

# In addition, when passing parameters on to APClient.bin, the following
# parameter is added:
# 17: Source node text (duplicate of Source node)

# If the log file has not be set, set the logfile to output to /dev/null
if [ -z "${logfile}" ]
then
   logfile=/dev/null
fi

touch "${logfile}"

echo Number of input arguments: ${#} >> $logfile
echo Input Arguments: >> $logfile
echo message_id: $1 >> $logfile 
message_id=$1;       shift
echo source_node: $1 >> $logfile 
source_node=$1;      shift
echo source_node_type: $1 >> $logfile 
source_node_type=$1; shift
echo date_created: $1 >> $logfile 
date_created=$1;     shift
echo time_created: $1 >> $logfile 
time_created=$1;     shift
echo date_received: $1 >> $logfile 
date_received=$1;    shift
echo time_received: $1 >> $logfile 
time_received=$1;    shift
echo application: $1 >> $logfile 
application=$1;      shift
echo message_group: $1 >> $logfile 
message_group=$1;    shift
echo object: $1 >> $logfile 
object=$1;    	     shift
echo severity: $1 >> $logfile 
severity=$1;  	     shift
echo operators: $1 >> $logfile 
operators=$1; 	     shift
echo message_text: $1 >> $logfile 
message_text=$1;     shift
echo instruction: $1 >> $logfile 
instruction=$1;      shift
echo cma: $1 >> $logfile 
cma=$1;              shift
echo sup_dups: $1 >> $logfile 
sup_dups=$1;         shift
echo next: $1 >> $logfile 
shift
echo next: $1 >> $logfile 
shift
echo next: $1 >> $logfile 
shift
echo next: $1 >> $logfile 
shift
echo next: $1 >> $logfile 
shift
echo next: $1 >> $logfile 
shift
echo next: $1 >> $logfile 


# Optionally Log the command
echo `date`: ${APClient} \"--map-data\" \"${client}\" \"${message_id}\" \"${source_node}\" \"${source_node_type}\" \"${date_created}\" \"${time_created}\" \"${date_received}\" \"${time_received}\" \"${application}\" \"${message_group}\" \"${object}\" \"${severity}\" \"${operators}\" \"${message_text}\" \"${instruction}\" \"${cma}\" \"${sup_dups}\" \"${source_node}\" >> "${logfile}"

# Inject Message to IAS
${APClient} "--map-data" "${client}" "${message_id}" "${source_node}" "${source_node_type}" "${date_created}" "${time_created}" "${date_received}" "${time_received}" "${application}" "${message_group}" "${object}" "${severity}" "${operators}" "${message_text}" "${instruction}" "${cma}" "${sup_dups}" "${source_node}"
RC=$?

# If the call to APClient.bin fails, A new OVO Event is created indicating the system 
# failed to send a message to xMatters.  As well the original OVO Event will be Annotated
if [ ${RC} -ne 0 ] ; then
    error_msg="System failed to send message ${message_id} to xMatters."
    # Annotate Event
    ${OpC}/opcannoadd "${message_id}" "${error_msg}"

    ## OVO Error Event

    # Optionally log the error
    echo `date`: "ERROR: msg_t=${error_msg} Original Event Message: ${message_text}" >> "${logfile}"
    
    # Tell OMU about the error
    ${OpC}/opcmsg "a=xMatters Integration Agent" o=APClient.bin "msg_g=${message_group}" sev=critical "msg_t=${error_msg} Original Event Message: ${message_text}"
    exit 1
fi

exit 0

#########################################################################
# end 
#########################################################################
