REM ***********************************************************************
REM File:        warning_messages.sql
REM Description: SQL*Plus script to get the last x active warning
REM              messages in OM-U
REM Language:    SQL*Plus
REM Package:     HP Operations Manager for UNIX AlarmPoint Integration
REM
REM (c) Copyright AlarmPoint Systems Inc 2008
REM ***********************************************************************

column message_number format A38 TRUNCATE
column severity format A10 TRUNCATE
column node_name format A64 TRUNCATE
column message_group format A32 TRUNCATE
column application format A54 TRUNCATE
column object format A54 TRUNCATE
column service_name format A64 TRUNCATE
column owned format A6 TRUNCATE
column owner format A24 TRUNCATE
column text_part format A128 TRUNCATE

set heading off
set echo off
set linesize 512
set pagesize 0
set feedback off
set newpage 0;
Set Verify Off
ttitle off;

select
        message_number, '|',
        severity, '|',
        node_name, '|',
        message_group, '|',
        application, '|',
        object, '|',
        service_name, '|',
        owned, '|',
        owner, '|',
        text_part
from
    (select
        am.creation_time,
        am.message_number,
        DECODE(am.severity, 2, 'normal', 4, 'warning', 8, 'critical',
                16, 'minor', 32, 'major', 'unknown') as severity,
        TRANSLATE(nn.node_name, '|', ' ') as node_name,
        TRANSLATE(am.message_group, '|', ' ') as message_group,
        TRANSLATE(am.application, '|', ' ') as application,
        TRANSLATE(am.object, '|', ' ') as object,
        TRANSLATE(am.service_name, '|', ' ') as service_name,
        DECODE(am.assign_flag, 0, 'false', 4, 'true') as owned,
        CASE when ea.type=4 then TRANSLATE(ea.op_name, '|', ' ') else TRANSLATE('', '|', ' ') END as owner,
        TRANSLATE(mt.text_part,CHR(13), ' ') as text_part
    from
        opc_act_messages   am left outer join opc_escal_assign_m ea on am.message_number = ea.message_number,
        opc_msg_text       mt,
        opc_node_names     nn,
        opc_user_data      ud,
        opc_op_realm       rm,
        opc_nodes_in_group ng
    where
              am.severity = '4'
        and   am.ackn_flag = 0
        and   am.message_number = mt.message_number
        and   mt.order_number = 1
        and   am.node_id = nn.node_id
        and   am.node_id = ng.node_id
        and   ng.node_group_id = rm.node_group_id
        and   am.message_group = rm.msg_group_name
        and   rm.user_id = ud.user_id
        and   ud.name = SUBSTR('&1', INSTR('&1', '-', 1, 1) + 1)
     order by 1 desc
     )
where rownum <= SUBSTR('&1', 1, INSTR('&1', '-', 1, 1) - 1);

quit;

