#!/bin/sh

#
# xMatters script to install integration files into the appropriate locations for HPUX
#
# This script will make backup copies of any existing files before overwriting them.
# All such files will have '.old' appended to their file name.
#
# Please look over the following settings to make sure they match your environment.
# Also, make sure that Operations Manager for Unix is currently running, so that
# the xMatters configuration for OM-U can be installed.
#

XM_INSTALL_DIR=`pwd`
XM_IA_DIR=/opt/xmatters/integrationagent
XM_INT_VER=hpoml-1-0-1
OMU_IA_DIR=${XM_IA_DIR}/integrationservices/${XM_INT_VER}
XM_USER=opc_op
XM_GROUP=opcgrp
OMU_BIN_DIR=/opt/OV/bin
OPC_DIR=${OMU_BIN_DIR}/OpC
OPC_CONF_DIR=/etc/opt/OV/share/conf/OpC
OMU_VERSION=rhel

# Copy Integration script, MG, library and APClient.bin shell script wrapper
if [ -f ${OMU_IA_DIR} ]
then
    cp -fR ${OMU_IA_DIR} ${OMU_IA_DIR}.old
fi
cp -fR ${XM_INSTALL_DIR}/components/integration-agent/${XM_INT_VER} ${XM_IA_DIR}/integrationservices
cp -fR ${XM_INSTALL_DIR}/components/integration-agent/lib ${XM_IA_DIR}
cp -fR ${XM_INSTALL_DIR}/components/integration-agent/conf ${XM_IA_DIR}

# Modify IAConfig.xml to include Integration script, deleting line if it previously existed
sed -e '/hpoml.xml/ d' -e '/<\/service-configs>/ i\
    <path>'${XM_INT_VER}'/hpoml.xml</path>
' ${XM_IA_DIR}/conf/IAConfig.xml > ${XM_IA_DIR}/conf/IAConfig.xml.new
mv -f ${XM_IA_DIR}/conf/IAConfig.xml ${XM_IA_DIR}/conf/IAConfig.xml.old
mv -f ${XM_IA_DIR}/conf/IAConfig.xml.new ${XM_IA_DIR}/conf/IAConfig.xml

# Copy XM-OMU-Bridge
if [ -f ${XM_IA_DIR}/bin/XM-OMU-Bridge ]
then
    cp -f ${XM_IA_DIR}/bin/XM-OMU-Bridge ${XM_IA_DIR}/bin/XM-OMU-Bridge.old
fi
cp -f ${XM_INSTALL_DIR}/components/integration-agent/bridge/rhel/XM-OMU-Bridge ${XM_IA_DIR}/bin/

# Install xMatters configurationn into HP Operations Manager
# Note that HPOM for Unix must be running in order for this to work
${OPC_DIR}/opccfgupld -replace ${XM_INSTALL_DIR}/components/oml/opccfg_${OMU_VERSION}

# Copy Severity adjustment scripts into place
# Note that these scripts are not backed up automatically
cp ${XM_INSTALL_DIR}/components/oml/sqlscripts/*.sql ${OPC_CONF_DIR}/mgmt_sv/reports/C/
chmod ug+rx ${OPC_CONF_DIR}/mgmt_sv/reports/C/*_messages.sql
chown ${XM_USER}:${XM_GROUP} ${OPC_CONF_DIR}/mgmt_sv/reports/C/*_messages.sql

# Adjust permissions on Integration Agent installation
chown -R ${XM_USER}:${XM_GROUP} ${XM_IA_DIR}
find ${XM_IA_DIR}/bin/ -type d | xargs chmod a+rx
find ${XM_IA_DIR}/bin/ -name 'APClient.bin' | xargs chmod a+rx
find ${XM_IA_DIR}/bin/ -name 'XM-OMU-Bridge' | xargs chmod a+rx
find ${OMU_IA_DIR}/ -name 'om_xmatters.sh' | xargs chmod a+rx
chmod 775 ${XM_IA_DIR}/log
